class KFWeapon extends Weapon
    abstract;

var() int ClipCount;
var() float ReloadRate;
var float ReloadTimer;
var bool bzoomed;
var float ZoomLevel;

var() sound ReloadBeginSound, ReloadSound, ReloadEndSound, ToggleSound;
var() name ReloadAnim;
var() float ReloadAnimRate;
var() bool bHoldToReload;

var name FlashBoneName;
var name TPAnim;

var bool bIsReloading, bReloadEffectDone;

replication
{
    reliable if(Role == ROLE_Authority)
        ClipCount;


    reliable if(Role < ROLE_Authority)
        ReloadMeNow, ActuallyFinishReloading;


    reliable if(Role == ROLE_Authority)
        ClientReload, ClientFinishReloading, ClientReloadEffects;
}

exec function ReloadMeNow()
{
    if(!AllowReload())
        return;

    bIsReloading = true;
    ReloadTimer = Level.TimeSeconds;
    PlaySound(ReloadBeginSound, SLOT_Misc, TransientSoundVolume,,TransientSoundRadius,, false);
    ClientReload();

}

simulated function ClientReload()
{
    bIsReloading = true;
    PlayAnim(ReloadAnim, ReloadAnimRate, 0.1);
}


simulated function ClientReloadEffects(){}


exec function FinishReloading()
{
   if(!bIsReloading)
        return;

   if(bHoldToReload)
       ActuallyFinishReloading();
}

//We shouldn't allow finishreloading to finish reloading unless
//the weapon works like that.
simulated function ActuallyFinishReloading()
{
   PlaySound(ReloadEndSound, SLOT_Misc, TransientSoundVolume,,TransientSoundRadius,, false);
   ClientFinishReloading();
   bIsReloading = false;
   bReloadEffectDone = false;
}

simulated function ClientFinishReloading()
{
    bIsReloading = false;
    PlayIdle();

    if(Instigator.PendingWeapon != none && Instigator.PendingWeapon != self)
        Instigator.Controller.ClientSwitchToBestWeapon();
}

function bool AllowReload()
{
    if(KFInvasionBot(Instigator.Controller) != None && !bIsReloading &&
        ClipCount < Default.ClipCount && AmmoAmount(0) > ClipCount)
        return true;
    if(FireMode[0].IsFiring() || FireMode[1].IsFiring() ||
           bIsReloading || ClipCount >= Default.ClipCount ||
           AmmoAmount(0)==0 || AmmoAmount(0) <= ClipCount)
        return false;
    return true;
}

simulated function bool PutDown()
{
    if(bIsReloading)
        return false;

    return Super.PutDown();
}

simulated function BringUp(optional Weapon PrevWeapon)
{
    Super.BringUp(PrevWeapon);
    bIsReloading = false;
}


simulated function bool ConsumeAmmo( int Mode, float Load, optional bool bAmountNeededIsMax )
{
    if( Super.ConsumeAmmo(Mode, Load, bAmountNeededIsMax) )
    {
        if( Load > 0 )
            ClipCount--;
        return true;
    }
    return false;
}

event WeaponTick(float dt)
{
    local float LastSeenSeconds;
    if(!bIsReloading)
    {

        if(!Instigator.IsHumanControlled())
        {
            LastSeenSeconds = Level.TimeSeconds - Instigator.Controller.LastSeenTime;
            if(ClipCount == 0 || ((LastSeenSeconds >= 5 || LastSeenSeconds > ClipCount) && ClipCount < Default.ClipCount))
                ReloadMeNow();
        }
    }
    else
    {

        if((Level.TimeSeconds - ReloadTimer) >= ReloadRate)
        {
            if(AmmoAmount(0) <= ClipCount && !bHoldToReload)
            {
                ClipCount = AmmoAmount(0);
                ActuallyFinishReloading();
            }
            else
            {
                PlaySound(ReloadSound, SLOT_Misc, TransientSoundVolume,,TransientSoundRadius,, false);

                InsertBullet();

                if(ClipCount < Default.ClipCount && ClipCount < AmmoAmount(0) && bHoldToReload)
                    ReloadTimer = Level.TimeSeconds;
                if(ClipCount >= Default.ClipCount || ClipCount >= AmmoAmount(0) || !bHoldToReload)
                    ActuallyFinishReloading();
            }
        }
        else if(bIsReloading && !bReloadEffectDone && Level.TimeSeconds - ReloadTimer >= ReloadRate / 2)
        {
            bReloadEffectDone = true;
            ClientReloadEffects();
        }
    }
}


function InsertBullet()
{
    ClipCount = Default.ClipCount;
}

simulated function DoToggle ()
{
  PlaySound(ToggleSound, SLOT_Misc, TransientSoundVolume,,TransientSoundRadius,, false);

}

simulated function float ChargeBar()
{
    local float CurrentClip, MaxClip;


    CurrentClip = ClipCount;
    MaxClip = Default.ClipCount;

    return FMin(1, CurrentClip/MaxClip);
}

function byte BestMode()
{
    return 0;
}

defaultproperties
{
bUseDynamicLights=false
bHoldToReload=false
FlashBoneName=Tip
bIsReloading=false
bReloadEffectDone=true
TPAnim=
}
